![PyPI - License](https://img.shields.io/pypi/l/pyIPCMI)
![GitHub tag (latest by date)](https://img.shields.io/github/v/tag/Paebbels/pyIPCMI) 
![GitHub release (latest by date)](https://img.shields.io/github/v/release/Paebbels/pyIPCMI)
[![Documentation Status](https://readthedocs.org/projects/pyipcmi/badge/?version=latest)](https://pyIPCMI.readthedocs.io/en/latest/?badge=latest)  
[![PyPI](https://img.shields.io/pypi/v/pyIPCMI)](https://pypi.org/project/pyIPCMI/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pyIPCMI)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/pyIPCMI)
![PyPI - Status](https://img.shields.io/pypi/status/pyIPCMI)


# The pyIPCMI - Service Tool

The complete Documentation is available on [pyIPCMI.ReadTheDocs.io](http://pyIPCMI.readthedocs.io/en/release/).
For a step by step introduction read our [Quick Start guide](http://pyIPCMI.readthedocs.io/en/release/QuickStart.html).
A detailed usage guide is provided in the sections of [Using pyIPCMI](http://pyIPCMI.readthedocs.io/en/release/UsingpyIPCMI/index.html).
Please also read [Tool Chain Specifics](http://pyIPCMI.readthedocs.io/en/release/ToolChains/index.html)
for special tool chain features. 

The references chapter provides a complete [command line argument](http://pyIPCMI.readthedocs.io/en/release/References/CmdRefs/pyIPCMI.html)
description for the service tool. In [IP Core Database](http://pyIPCMI.readthedocs.io/en/release/References/Database.html)
we are describing how the IP Core database works so a user can integrate own cores into our repository and infrastructure.
pyIPCMI own file formats are documented [here](http://pyIPCMI.readthedocs.io/en/release/References/FileFormats/index.html).
And finally, all Python packages, modules and classes are automatically documented by DocUtils/Sphinx in
[Python Infrastructure](http://pyIPCMI.readthedocs.io/en/release/PyInfrastructure/index.html).




## Contributors:

* [Patrick Lehmann](https://github.com/Paebbels) (Maintainer)
* [Martin Zabel](https://github.com/mzabeltud)

## License

This library is licensed under [Apache License 2.0](LICENSE.md)

-------------------------

SPDX-License-Identifier: Apache-2.0
